==> wildfly-dist-21.0.0.Final-src.tar.gz: wildfly-21.0.0.Final-src/clustering/web/spi/src/main/java/org/wildfly/clustering/web/sso/SSOManagerConfiguration.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.web.sso;

import org.wildfly.clustering.marshalling.spi.MarshalledValueFactory;
import org.wildfly.clustering.web.IdentifierFactory;
import org.wildfly.clustering.web.LocalContextFactory;

/**
 * @author Paul Ferraro
 * @param <C> marshalling context type
 * @param <L> local context type
 */
public interface SSOManagerConfiguration<C, L> {
    IdentifierFactory<String> getIdentifierFactory();
    MarshalledValueFactory<C> getMarshalledValueFactory();
    LocalContextFactory<L> getLocalContextFactory();
}

==> wildfly-dist-26.1.0.Final-src.tar.gz: wildfly-26.1.0.Final-src/clustering/web/spi/src/main/java/org/wildfly/clustering/web/sso/SSOManagerConfiguration.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.web.sso;

import java.util.function.Supplier;

import org.wildfly.clustering.marshalling.spi.MarshalledValueFactory;
import org.wildfly.clustering.web.LocalContextFactory;

/**
 * @author Paul Ferraro
 * @param <C> marshalling context type
 * @param <L> local context type
 */
public interface SSOManagerConfiguration<C, L> {
    Supplier<String> getIdentifierFactory();
    MarshalledValueFactory<C> getMarshalledValueFactory();
    LocalContextFactory<L> getLocalContextFactory();
}
